@@ -1,8 +1,8 @@
-from redis.asyncio import Redis
+from redis.asyncio import ConnectionPool, Redis
 from fastapi import APIRouter
 from fastapi.param_functions import Depends
 
-from {{cookiecutter.project_name}}.services.redis.dependency import get_redis_connection
+from {{cookiecutter.project_name}}.services.redis.dependency import get_redis_pool
 from {{cookiecutter.project_name}}.web.api.redis.schema import RedisValueDTO
 
 router = APIRouter()
@@ -11,16 +11,17 @@ router = APIRouter()
 @router.get("/", response_model=RedisValueDTO)
 async def get_redis_value(
     key: str,
-    redis: Redis = Depends(get_redis_connection),
+    redis_pool: ConnectionPool = Depends(get_redis_pool),
 ) -> RedisValueDTO:
     """
     Get value from redis.
 
     :param key: redis key, to get data from.
-    :param redis: redis connection.
+    :param redis_pool: redis connection pool.
     :returns: information from redis.
     """
-    redis_value = await redis.get(key)
+    async with Redis(connection_pool=redis_pool) as redis:
+        redis_value = await redis.get(key)
     return RedisValueDTO(
         key=key,
         value=redis_value,
@@ -30,13 +31,14 @@ async def get_redis_value(
 @router.put("/")
 async def set_redis_value(
     redis_value: RedisValueDTO,
-    redis: Redis = Depends(get_redis_connection),
+    redis_pool: ConnectionPool = Depends(get_redis_pool),
 ) -> None:
     """
     Set value in redis.
 
     :param redis_value: new value data.
-    :param redis: redis connection.
+    :param redis_pool: redis connection pool.
     """
     if redis_value.value is not None:
-        await redis.set(name=redis_value.key, value=redis_value.value)
+        async with Redis(connection_pool=redis_pool) as redis:
+            await redis.set(name=redis_value.key, value=redis_value.value)
